@@ -54,7 +54,7 @@
 #define ROB_FILE_LENGTH 256
 #define ROB_ERROR_LENGTH 256
 
-#define ROB_DIR "rob/"
+#define ROB_DIR "rob"
 #define ROB_SPRITES "robsprites.bmp"
 
 #define ROB_SPRITES_POINTER_XOFFSET 0
@@ -123,7 +123,7 @@ void ROB_Init(ROB_OpEnv *op_env) {
 	}
 
 	/* Load the ROB system images */
-	strcpy(filename, PACKAGE_DATA_DIR ROB_DIR);
+	strcpy(filename, PACKAGE_DATA_DIR "/" ROB_DIR "/");
 	strcat(filename, ROB_SPRITES);
 	/* Load the bitmap */
 	if ((unconverted = SDL_LoadBMP(filename)) == NULL) {
