@@ -569,6 +569,8 @@ void set_default_user_controls (struct control user_controls[USER_CONTROLS])
 			user_controls[count].device = DEVICE_JOYSTICK;
 		#elif defined(PLATFORM_ZAURUS)
 			user_controls[count].device = DEVICE_KEYBOARD;
+		#elif defined(PLATFORM_FREMANTLE)
+			user_controls[count].device = DEVICE_KEYBOARD;
 		#elif defined(PLATFORM_PSP)
 			user_controls[count].device = DEVICE_JOYSTICK;
 		#endif
@@ -684,7 +686,7 @@ void set_default_user_controls (struct control user_controls[USER_CONTROLS])
 			user_controls[ACTION_PRIMARY_CLICK].device = DEVICE_MOUSE;
 			user_controls[ACTION_PRIMARY_CLICK].id = SDL_BUTTON_LEFT;
 		#else
-			user_controls[ACTION_PRIMARY_CLICK].id = UNDEFINED;
+			user_controls[ACTION_PRIMARY_CLICK].device = UNDEFINED;
 		#endif
 		user_controls[ACTION_NOT_USED1].device = UNDEFINED;
 	#elif defined(PLATFORM_ZAURUS)
@@ -732,6 +734,52 @@ void set_default_user_controls (struct control user_controls[USER_CONTROLS])
 		user_controls[ACTION_PRIMARY_CLICK].device = DEVICE_MOUSE;
 		user_controls[ACTION_PRIMARY_CLICK].id = SDL_BUTTON_LEFT;
 		user_controls[ACTION_NOT_USED1].device = UNDEFINED;
+	#elif defined(PLATFORM_FREMANTLE)
+		user_controls[ACTION_UP].id = SDLK_UP;
+		user_controls[ACTION_UP_RIGHT].device = UNDEFINED;
+		user_controls[ACTION_RIGHT].id = SDLK_RIGHT;
+		user_controls[ACTION_DOWN_RIGHT].device = UNDEFINED;
+		user_controls[ACTION_DOWN].id = SDLK_DOWN;
+		user_controls[ACTION_DOWN_LEFT].device = UNDEFINED;
+		user_controls[ACTION_LEFT].id = SDLK_LEFT;
+		user_controls[ACTION_UP_LEFT].device = UNDEFINED;
+		user_controls[ACTION_RESTART].id = SDLK_r;
+		user_controls[ACTION_SHOOT_UP].id = SDLK_UP;
+		user_controls[ACTION_SHOOT_UP].mod = ACTION_MODIFIER2;
+		user_controls[ACTION_SHOOT_DOWN].id = SDLK_DOWN;
+		user_controls[ACTION_SHOOT_DOWN].mod = ACTION_MODIFIER2;
+		user_controls[ACTION_SHOOT_LEFT].id = SDLK_LEFT;
+		user_controls[ACTION_SHOOT_LEFT].mod = ACTION_MODIFIER2;
+		user_controls[ACTION_SHOOT_RIGHT].id = SDLK_RIGHT;
+		user_controls[ACTION_SHOOT_RIGHT].mod = ACTION_MODIFIER2;
+		user_controls[ACTION_SELECT].id = SDLK_KP_ENTER;
+		user_controls[ACTION_EXIT].id = SDLK_BACKSPACE;
+		user_controls[ACTION_HELP].id = SDLK_h;
+		user_controls[ACTION_OPTIONS].id = SDLK_o;
+		user_controls[ACTION_TOGGLE_FULLSCREEN].id = SDLK_RETURN;
+		user_controls[ACTION_TOGGLE_FULLSCREEN].mod = ACTION_MODIFIER1;
+		user_controls[ACTION_PREVIOUS_LEVEL].id = SDLK_F5;
+		user_controls[ACTION_NEXT_LEVEL].id = SDLK_F6;
+		user_controls[ACTION_PREVIOUS_PACK].id = SDLK_F7;
+		user_controls[ACTION_NEXT_PACK].id = SDLK_F8;
+		user_controls[ACTION_HOME].id = SDLK_HOME;
+		user_controls[ACTION_END].id = SDLK_END;
+		user_controls[ACTION_PAGEUP].id = SDLK_PAGEUP;
+		user_controls[ACTION_PAGEDOWN].id = SDLK_PAGEDOWN;
+		user_controls[ACTION_TOGGLE_DESIGNER].id = SDLK_F9;
+		user_controls[ACTION_VOLUP].id = SDLK_EQUALS;
+		user_controls[ACTION_VOLDOWN].id = SDLK_MINUS;
+		user_controls[ACTION_MODIFIER1].id = SDLK_MODE;
+		user_controls[ACTION_MODIFIER2].id = SDLK_LSHIFT;
+		user_controls[ACTION_MODIFIER3].device = UNDEFINED;
+		user_controls[ACTION_MODIFIER4].device = UNDEFINED;
+		user_controls[ACTION_SCROLL_UP].device = DEVICE_MOUSE;
+		user_controls[ACTION_SCROLL_UP].id = SDL_BUTTON_WHEELUP;
+		user_controls[ACTION_SCROLL_DOWN].device = DEVICE_MOUSE;
+		user_controls[ACTION_SCROLL_DOWN].id = SDL_BUTTON_WHEELDOWN;
+		user_controls[ACTION_PRIMARY_CLICK].device = DEVICE_MOUSE;
+		user_controls[ACTION_PRIMARY_CLICK].id = SDL_BUTTON_LEFT;
+		user_controls[ACTION_NOT_USED1].device = UNDEFINED;
 	#elif defined(PLATFORM_PSP)
 		user_controls[ACTION_UP].id = PSP_UP;
 		user_controls[ACTION_UP_RIGHT].device = UNDEFINED;
@@ -833,6 +881,9 @@ int initialise_joystick (int joyid, char *joyname, int show)
 		#elif defined(PLATFORM_ZAURUS)
 			if (joystick)
 			{
+		#elif defined(PLATFORM_FREMANTLE)
+			if (joystick)
+			{
 		#elif defined(PLATFORM_PSP)
 			if (joystick)
 			{
@@ -1580,8 +1631,8 @@ void get_input_device_text (int device, int id, char *joyname, char *text)
 					break;
 			}
 		}
-		else if ((strcmp (joyname, "PEP Joy")) == 0)
-		{	/* GP2X F100 joystick */
+		else if ((strcmp (joyname, "PEP Joy") == 0) || (strcmp (joyname, "GP2X_JOYSTICK") == 0))
+		{	/* GP2X F100/F200 joystick */
 			switch (id)
 			{
 				case GP2X_JOY_N:
