@@ -19,7 +19,7 @@ int             viewh;
  * first we declare all the objects on the objects bar 
  */
 struct k_icon_init K_icons_list[] = {
-    {11, 3, KGAMEOBJ, EMPTY_FIELD, -1},
+    {12, 8, KGAMEOBJ, EMPTY_FIELD, -1},
     {3, 6, KGAMEOBJ, ROBBO, 0},
     {1, 1, KGAMEOBJ, MAGNET, 0},
     {2, 1, KGAMEOBJ, MAGNET, 2},
@@ -41,12 +41,12 @@ struct k_icon_init K_icons_list[] = {
     {9, 1, KGAMEOBJ, BOMB, -1},
     {10, 1, KGAMEOBJ, DOOR, -1},
     {6, 2, KGAMEOBJ, CAPSULE, -1},
-    {9, 2, KGAMEOBJ, PUSH_BOX, -1},
-    {3, 7, KGAMEOBJ, BARBED_WIRE, -1},
+    {7, 7, KGAMEOBJ, PUSH_BOX, -1},
+    {3, 7, KGAMEOBJ, RADIOACTIVE_FIELD, -1},
     {5, 7, KGAMEOBJ, STOP, -1},
     {10, 4, KGAMEOBJ, BARRIER, -1},
     {1, 5, KGAMEOBJ, TELEPORT, -1},
-    {5, 3, KGAMEOBJ, GROUND, -1},
+    {6, 7, KGAMEOBJ, GROUND, -1},
     {3, 1, KGAMEOBJ, WALL, -1},
     {1, 4, KGAMEOBJ, K_LASER, -1},
     {0, 0, KOBJ_S, K_LTYPE, -1},
@@ -99,6 +99,7 @@ int             eraser = 0;	/* unused */
 int             insert = 0;	/* flag that shows if we would insert
 				 * level, during save, or replace */
 int             gsize = 0;
+int 		bombtype=0;  /* regular bomb */
 int             wallnumber = 0;
 int             selected = -1;	/* selected icon */
 int             txt_x,
@@ -244,7 +245,7 @@ konstruktor_init()
     else if (level.w == 32 && level.h == 31)
 	gsize = 1;
     inforedraw = 1;
-    sprintf(infostring, "Welcome to GNU Robbo Designer");
+    sprintf(infostring, txt_konstruktor_Welcome_to_GNU_Robbo_Designer);
     robbo.keys = k_count_obj(KEY);	/* count keys on a map */
     robbo.bullets = k_count_obj(BULLET) * 9;	/* count bullets */
     game_area.redraw = REDRAW_EVERYTHING;
@@ -288,9 +289,9 @@ konstruktor_end()
 void
 konstruktor_animate(void)
 {
-    int             x,
+    int        temp_direction,     x,
                     y;
-
+	
     /*
      * Now iterate through every board location updating objects 
      */
@@ -300,7 +301,7 @@ konstruktor_animate(void)
 	     * decrement rotation delay counter if it is a gun, and needs
 	     * it 
 	     */
-	    if ((board[x][y].type == GUN) && (board[x][y].rotated > 0))
+	    if ((board[x][y].type == GUN || board[x][y].type==MAGNET) && (board[x][y].rotated > 0))
 		board[x][y].rotated--;	/* Decrement rotation delay */
 	    /*
 	     * Decrement the object's delay and then check if it needs
@@ -319,7 +320,7 @@ konstruktor_animate(void)
 		case BIRD:
 		case BUTTERFLY:
 		case CAPSULE:
-		case BARBED_WIRE:
+		case RADIOACTIVE_FIELD:
 		    board[x][y].moved = DELAY_KONSTRUKTOR;
 		    negate_state(x, y);
 		    break;
@@ -337,8 +338,13 @@ konstruktor_animate(void)
 		case GUN:
 		    if (board[x][y].rotable)
 			if (board[x][y].rotated == 0) {
-			    if (board[x][y].randomrotated)
-				board[x][y].direction = rand() & 0x03;
+			    if (board[x][y].randomrotated) {
+				temp_direction=rand() & 0x03;
+					if(board[x][y].movable==1) {
+						board[x][y].direction2=abs(board[x][y].direction2+(temp_direction-board[x][y].direction)) % 4;
+						} 
+					board[x][y].direction = temp_direction;
+				}
 			    else
 				board[x][y].direction =
 				    (board[x][y].direction + 1) & 0x03;
@@ -347,6 +353,17 @@ konstruktor_animate(void)
 			}
 		    board[x][y].state = board[x][y].direction;
 		    break;
+		case MAGNET:
+		    if (board[x][y].rotable)
+			if (board[x][y].rotated == 0) {
+			    temp_direction=rand() & 0x03;
+			    board[x][y].direction = temp_direction;
+			    board[x][y].rotated = DELAY_ROTATION;
+			    redraw_field(x, y);
+			}
+		    board[x][y].state = board[x][y].direction;
+		    break;
+
 		}
 	    }
 	}
@@ -403,7 +420,7 @@ konstruktor_show_game_area(void)
 	lastclick--;
     play_music();
     if (game_area.redraw >= REDRAW_EVERYTHING) {
-	k_redraw_all();;
+	k_redraw_all();
 	clear_screen();
 	scoreline.redraw = 0xff;
     }
@@ -510,7 +527,7 @@ konstruktor_show_game_area(void)
 			SDL_BlitSurface(k_icons, &srcrect, screen,
 					&destrect);
 		    }
-
+		 if(board[x][y].type==GUN && board[x][y].movable==1) board[x][y].state=board[x][y].direction+4;
 		    srcrect =
 			set_rect(board[x][y].icon[board[x][y].state].x,
 				 board[x][y].icon[board[x][y].state].y,
@@ -543,22 +560,24 @@ konstruktor_show_game_area(void)
 			SDL_BlitSurface(k_icons, &srcrect, screen,
 					&destrect);
 			break;
+		    case MAGNET:
+			if (board[x][y].rotable) {
+			    k_geticoncoords(6, 1, &srcrect);
+			    SDL_BlitSurface(k_icons, &srcrect, screen, &destrect);
+			}
+			break;			
 		    case GUN:
 			nx = 7;
 			ny = ((board[x][y].solidlaser + 2) % 3) + 1;
 			k_geticoncoords(nx, ny, &srcrect);
-			SDL_BlitSurface(k_icons, &srcrect, screen,
-					&destrect);
+			SDL_BlitSurface(k_icons, &srcrect, screen, &destrect);
 			if (board[x][y].movable) {
-			    k_geticoncoords(5, board[x][y].direction2 + 5,
-					    &srcrect);
-			    SDL_BlitSurface(k_icons, &srcrect, screen,
-					    &destrect);
+			    k_geticoncoords(5, board[x][y].direction2 + 5, &srcrect);
+			    SDL_BlitSurface(k_icons, &srcrect, screen, &destrect);
 			}
 			if (board[x][y].rotable) {
 			    k_geticoncoords(6, 1, &srcrect);
-			    SDL_BlitSurface(k_icons, &srcrect, screen,
-					    &destrect);
+			    SDL_BlitSurface(k_icons, &srcrect, screen, &destrect);
 			}
 
 			break;
@@ -662,49 +681,75 @@ konstruktor_click()
 	    
 	    if (K_icons[selected].game_obj != K_LASER)
 		create_object(nx, ny, K_icons[selected].game_obj);
-		
+		if(K_icons[selected].game_obj == BOMB && bombtype==1)						
+		create_object(nx, ny, BOMB2
+);
 	    switch (K_icons[selected].game_obj) {
 	    case GROUND:
-		sprintf(infostring, "Ground");
+		sprintf(infostring, txt_konstruktor_Ground);
 		break;
 	    case STOP:
-		sprintf(infostring, "Stop (%d on map)",
-			k_count_obj(STOP));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Stop,
+			k_count_obj(STOP),
+			txt_konstruktor_on_map);
 		break;
-	    case BARBED_WIRE:
-		sprintf(infostring, "Radioactive Field (%d on map)",
-			k_count_obj(BARBED_WIRE));
+	    case RADIOACTIVE_FIELD:
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Radioactive_Field,
+			k_count_obj(RADIOACTIVE_FIELD),
+			txt_konstruktor_on_map);
 		break;
 	    case PUSH_BOX:
-		sprintf(infostring, "Push Box (%d on map)",
-			k_count_obj(PUSH_BOX));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Push_Box,
+			k_count_obj(PUSH_BOX),
+			txt_konstruktor_on_map);
 		break;
 	    case CAPSULE:
-		sprintf(infostring, "Capsule (%d on map)",
-			k_count_obj(CAPSULE));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Capsule,
+			k_count_obj(CAPSULE),
+			txt_konstruktor_on_map);
 		break;
 	    case BOMB:
-		sprintf(infostring, "Bomb (%d on map)",
-			k_count_obj(BOMB));
+		if (bombtype==0) {
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Bomb,
+			k_count_obj(BOMB),
+			txt_konstruktor_on_map);
+		} else { 
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Bomb2,
+			k_count_obj(BOMB2),
+			txt_konstruktor_on_map);
+		}
 		break;
 	    case DOOR:
-		sprintf(infostring, "Door (%d on map)",
-			k_count_obj(DOOR));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Door,
+			k_count_obj(DOOR),
+			txt_konstruktor_on_map);
 		break;
 	    case BOX:
-		sprintf(infostring, "Box (%d on map)",
-			k_count_obj(BOX));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Box,
+			k_count_obj(BOX),
+			txt_konstruktor_on_map);
 		break;
 	    case QUESTIONMARK:
-		sprintf(infostring, "? (%d on map)",
-			k_count_obj(QUESTIONMARK));
+		sprintf(infostring, "? (%d %s)",
+			k_count_obj(QUESTIONMARK),
+			txt_konstruktor_on_map);
 		break;
 	    case EMPTY_FIELD:
-		sprintf(infostring, "Empty Field");
+		sprintf(infostring, txt_konstruktor_Empty_Field);
 		break;
 	    case BUTTERFLY:
-		sprintf(infostring, "Butterfly (%d on map)",
-			k_count_obj(BUTTERFLY));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Butterfly,
+			k_count_obj(BUTTERFLY),
+			txt_konstruktor_on_map);
 		break;
 	    case K_LASER:
 		if (direction == 0 || direction == 2) {
@@ -713,31 +758,39 @@ konstruktor_click()
 		    create_object(nx, ny, LASER_D);
 		}
 		board[nx][ny].direction = direction;
-		sprintf(infostring, "Gun Fire (%d on map)",
-			k_count_obj(LASER_L) + k_count_obj(LASER_D));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Gun_Fire,
+			k_count_obj(LASER_L) + k_count_obj(LASER_D),
+			txt_konstruktor_on_map);
 		break;
 	    case BARRIER:
 		board[nx][ny].direction = (direction >= 2) ? 2 : 0;
-		sprintf(infostring, "Force Field (%d on map)",
-			k_count_obj(BARRIER));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Force_Field,
+			k_count_obj(BARRIER),
+			txt_konstruktor_on_map);
 		break;
 	    case SCREW:
 		robbo.screws++;
-		sprintf(infostring, "Screw (%d on map)",
-			k_count_obj(SCREW));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Screw,
+			k_count_obj(SCREW),
+			txt_konstruktor_on_map);
 		game_area.redraw = REDRAW_EVERYTHING;
 		break;
 	    case WALL:
-		board[nx][ny].state = wallnumber;;
+		board[nx][ny].state = wallnumber;
 		if (wallnumber != 3)
-		    sprintf(infostring, "Wall");
+		    sprintf(infostring, txt_konstruktor_Wall);
 		else
-		    sprintf(infostring, "Black Wall");
+		    sprintf(infostring, txt_konstruktor_Black_Wall);
 		break;
 	    case TELEPORT:
 		board[nx][ny].teleportnumber = teleportnr;
-		sprintf(infostring, "Teleport (%d on map)",
-			k_count_obj(TELEPORT));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Teleport,
+			k_count_obj(TELEPORT),
+			txt_konstruktor_on_map);
 		break;
 	    case GUN:
 		board[nx][ny].solidlaser = (ltype + 1) % 3;
@@ -748,44 +801,59 @@ konstruktor_click()
 		board[nx][ny].rotated = 0;
 		board[nx][ny].rotable = rotable;
 		board[nx][ny].randomrotated = 1;
-		sprintf(infostring, "Gun (%d on map)",
-			k_count_obj(GUN));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Gun,
+			k_count_obj(GUN),
+			txt_konstruktor_on_map);
 		break;
 	    case MAGNET:
 		board[nx][ny].direction = K_icons[selected].direction;
 		board[nx][ny].state = K_icons[selected].direction;
-		sprintf(infostring, "Magnet (%d on map)",
-			k_count_obj(MAGNET));
+		board[nx][ny].rotable=rotable;
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Magnet,
+			k_count_obj(MAGNET),
+			txt_konstruktor_on_map);
 		break;
 	    case BEAR:
 	    case BEAR_B:
 		board[nx][ny].direction = direction;
 		board[nx][ny].state = 0;
 		if (board[nx][ny].type == BEAR)
-		    sprintf(infostring, "Bear (%d on map)",
-		        k_count_obj(BEAR));
+		    sprintf(infostring, "%s (%d %s)",
+		        txt_konstruktor_Bear,
+		        k_count_obj(BEAR),
+				txt_konstruktor_on_map);
 		else
-		    sprintf(infostring, "Black Bear (%d on map)",
-		        k_count_obj(BEAR_B));
+		    sprintf(infostring, "%s (%d %s)",
+		        txt_konstruktor_Black_Bear,
+		        k_count_obj(BEAR_B),
+				txt_konstruktor_on_map);
 		break;
 	    case BIRD:
 		board[nx][ny].direction = direction;
 		board[nx][ny].direction2 = 1;
 		board[nx][ny].state = 0;
 		board[nx][ny].shooting = shooting;
-		sprintf(infostring, "Bird (%d on map)",
-			k_count_obj(BIRD));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Bird,
+			k_count_obj(BIRD),
+			txt_konstruktor_on_map);
 		break;
 	    case KEY:
 		robbo.keys++;
-		sprintf(infostring, "Key (%d on map)",
-			k_count_obj(KEY));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Key,
+			k_count_obj(KEY),
+			txt_konstruktor_on_map);
 		game_area.redraw = REDRAW_EVERYTHING;
 		break;
 	    case BULLET:
 		robbo.bullets = robbo.bullets + 9;
-		sprintf(infostring, "Bullets (%dx9 on map)",
-			k_count_obj(BULLET));
+		sprintf(infostring, "%s (%dx9 %s)",
+			txt_konstruktor_Bullets,
+			k_count_obj(BULLET),
+			txt_konstruktor_on_map);
 		game_area.redraw = REDRAW_EVERYTHING;
 		break;
 	    };
@@ -806,14 +874,16 @@ konstruktor_click()
 	    switch (K_icons[cnt].game_obj) {
 	    case -1:
 		return;
-	    case BARBED_WIRE:
-		sprintf(infostring, "Radioactive Field (%d on map)",
-			k_count_obj(BARBED_WIRE));
+	    case RADIOACTIVE_FIELD:
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Radioactive_Field,
+			k_count_obj(RADIOACTIVE_FIELD),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case K_RELOAD:
 		if (cnt == lastselected) {
-		    sprintf(infostring, "Level reloaded");
+		    sprintf(infostring, txt_konstruktor_Level_reloaded);
 		    clear_screen();
 		    level_init();
 		    konstruktor_viewport_init();
@@ -821,11 +891,8 @@ konstruktor_click()
 			gsize = 0;
 		    else if (level.w == 32 && level.h == 31)
 			gsize = 1;
-		    robbo.keys = k_count_obj(KEY);	/* count keys on a 
-							 * map */
-		    robbo.bullets = k_count_obj(BULLET) * 9;	/* count
-								 * bullets 
-								 */
+		    robbo.keys = k_count_obj(KEY);	/* count keys on a map */
+		    robbo.bullets = k_count_obj(BULLET) * 9;	/* count bullets  */
 		    game_area.redraw = REDRAW_EVERYTHING;
 		    k_view.x = 0;
 		    k_view.y = 0;
@@ -834,24 +901,31 @@ konstruktor_click()
 		    k_redraw_all();
 		    cnt = -1;
 		} else {
-		    sprintf(infostring, "Reload level - select again to reload");
+		    sprintf(infostring,
+		    	txt_konstruktor_Reload_level_select_again_to_reload);
 		    lastclick = 50;
 		};
 		inforedraw = 1;
 		break;
 	    case STOP:
-		sprintf(infostring, "Stop (%d on map)",
-			k_count_obj(STOP));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Stop,
+			k_count_obj(STOP),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case BARRIER:
-		sprintf(infostring, "Force Field (%d on map)",
-			k_count_obj(BARRIER));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Force_Field,
+			k_count_obj(BARRIER),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case MAGNET:
-		sprintf(infostring, "Magnet (%d on map)",
-			k_count_obj(MAGNET));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Magnet,
+			k_count_obj(MAGNET),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case ROBBO:
@@ -859,122 +933,162 @@ konstruktor_click()
 		inforedraw = 1;
 		break;
 	    case GUN:
-		sprintf(infostring, "Gun (%d on map)",
-			k_count_obj(GUN));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Gun,
+			k_count_obj(GUN),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case BEAR:
-		sprintf(infostring, "Bear (%d on map)",
-			k_count_obj(BEAR));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Bear,
+			k_count_obj(BEAR),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case BEAR_B:
-		sprintf(infostring, "Black Bear (%d on map)",
-			k_count_obj(BEAR_B));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Black_Bear,
+			k_count_obj(BEAR_B),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case BUTTERFLY:
-		sprintf(infostring, "Butterfly (%d on map)",
-			k_count_obj(BUTTERFLY));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Butterfly,
+			k_count_obj(BUTTERFLY),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case BOMB:
-		sprintf(infostring, "Bomb (%d on map)",
-			k_count_obj(BOMB));
+		if (cnt== selected) 
+			bombtype=(bombtype+1) %2;
+		if(bombtype==0) {
+			sprintf(infostring, "%s (%d %s)",
+				txt_konstruktor_Bomb,
+				k_count_obj(BOMB),
+				txt_konstruktor_on_map);
+		} else {
+			sprintf(infostring, "%s (%d %s)",
+				txt_konstruktor_Bomb2,
+				k_count_obj(BOMB2),
+				txt_konstruktor_on_map);
+		}
 		inforedraw = 1;
 		break;
 	    case DOOR:
-		sprintf(infostring, "Door (%d on map)",
-			k_count_obj(DOOR));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Door,
+			k_count_obj(DOOR),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case BULLET:
-		sprintf(infostring, "Bullets (%dx9 on map)",
-			k_count_obj(BULLET));
+		sprintf(infostring, "%s (%dx9 %s)",
+			txt_konstruktor_Bullets,
+			k_count_obj(BULLET),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case BOX:
-		sprintf(infostring, "Box (%d on map)",
-			k_count_obj(BOX));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Box,
+			k_count_obj(BOX),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case KEY:
-		sprintf(infostring, "Key (%d on map)",
-			k_count_obj(KEY));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Key,
+			k_count_obj(KEY),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case CAPSULE:
-		sprintf(infostring, "Capsule (%d on map)",
-			k_count_obj(CAPSULE));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Capsule,
+			k_count_obj(CAPSULE),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case PUSH_BOX:
-		sprintf(infostring, "Push Box (%d on map)",
-			k_count_obj(PUSH_BOX));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Push_Box,
+			k_count_obj(PUSH_BOX),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case SCREW:
-		sprintf(infostring, "Screw (%d on map)",
-			k_count_obj(SCREW));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Screw,
+			k_count_obj(SCREW),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case EMPTY_FIELD:
-		sprintf(infostring, "Empty Field");
+		sprintf(infostring, txt_konstruktor_Empty_Field);
 		inforedraw = 1;
 		break;
 	    case WALL:
 		if (cnt == selected)
 		    wallnumber = (wallnumber + 1) % 9;
 		if (wallnumber != 3)
-		    sprintf(infostring, "Wall");
+		    sprintf(infostring, txt_konstruktor_Wall);
 		else
-		    sprintf(infostring, "Black Wall");
+		    sprintf(infostring, txt_konstruktor_Black_Wall);
 		inforedraw = 1;
 		break;
 	    case K_LASER:
-		sprintf(infostring, "Gun Fire (%d on map)",
-			k_count_obj(LASER_L) + k_count_obj(LASER_D));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Gun_Fire,
+			k_count_obj(LASER_L) + k_count_obj(LASER_D),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case TELEPORT:
-		sprintf(infostring, "Teleport (%d on map)",
-			k_count_obj(TELEPORT));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Teleport,
+			k_count_obj(TELEPORT),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 
 		if (cnt == selected)
 		    teleportnr = (teleportnr % 11) + 1;
 		break;
 	    case GROUND:
-		sprintf(infostring, "Ground");
+		sprintf(infostring, txt_konstruktor_Ground);
 		inforedraw = 1;
 		break;
 	    case BIRD:
-		sprintf(infostring, "Bird (%d on map)",
-			k_count_obj(BIRD));
+		sprintf(infostring, "%s (%d %s)",
+			txt_konstruktor_Bird,
+			k_count_obj(BIRD),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 
 		if (cnt == selected)
 		    shooting = (shooting + 1) % 2;
 		break;
 	    case QUESTIONMARK:
-		sprintf(infostring, "? (%d on map)",
-			k_count_obj(QUESTIONMARK));
+		sprintf(infostring, "? (%d %s)",
+			k_count_obj(QUESTIONMARK),
+			txt_konstruktor_on_map);
 		inforedraw = 1;
 		break;
 	    case K_DIRECTION:
 	    direction = (direction + 1) % 4;
 	    switch (direction) {
 	        case 0:
-	        sprintf(infostring, "Direction right");
+	        sprintf(infostring, txt_konstruktor_Direction_right);
 	        break;
 	        case 1:
-	        sprintf(infostring, "Direction down");
+	        sprintf(infostring, txt_konstruktor_Direction_down);
 	        break;
 	        case 2:
-	        sprintf(infostring, "Direction left");
+	        sprintf(infostring, txt_konstruktor_Direction_left);
 	        break;
 	        case 3:
-	        sprintf(infostring, "Direction up");
+	        sprintf(infostring, txt_konstruktor_Direction_up);
 	        break;
 		}
 		inforedraw = 1;
@@ -983,14 +1097,13 @@ konstruktor_click()
 		ltype = (ltype + 1) % 3;
 		switch (ltype) {
 		case 0:
-		    sprintf(infostring, "Laser Gun");
+		    sprintf(infostring, txt_konstruktor_Laser_Gun);
 		    break;
 		case 1:
-		    sprintf(infostring, "Blaster Gun");
+		    sprintf(infostring, txt_konstruktor_Blaster_Gun);
 		    break;
 		case 2:
-		    sprintf(infostring,
-			    "Regular Gun");
+		    sprintf(infostring, txt_konstruktor_Regular_Gun);
 		    break;
 		}
 		inforedraw = 1;
@@ -1001,23 +1114,23 @@ konstruktor_click()
 		movable = (rmstate & 1);
 	    switch (rmstate) {
 	        case 0:
-	        sprintf(infostring, "Fixed Gun");
+	        sprintf(infostring, txt_konstruktor_Fixed);
 	        break;
 	        case 1:
-	        sprintf(infostring, "Moveable Gun");
+	        sprintf(infostring, txt_konstruktor_Moveable);
 	        break;
 	        case 2:
-	        sprintf(infostring, "Rotating Gun");
+	        sprintf(infostring, txt_konstruktor_Rotating);
 	        break;
 	        case 3:
-	        sprintf(infostring, "Moveable Rotating Gun");
+	        sprintf(infostring, txt_konstruktor_Moveable_Rotating);
 	        break;
 		}
 		inforedraw = 1;
 		break;
 	    case K_INSERT:
 		if (lastselected == cnt) {
-		    sprintf(infostring, "Level created");
+		    sprintf(infostring, txt_konstruktor_Level_created);
 		    insert = 1;
 		    /*
 		     * Clear board 
@@ -1042,7 +1155,7 @@ konstruktor_click()
 
 		} else {
 		    sprintf(infostring,
-			    "New level - select again to create");
+		    	txt_konstruktor_New_level_select_again_to_create);
 		    lastclick = 50;
 		}
 		inforedraw = 1;
@@ -1052,7 +1165,7 @@ konstruktor_click()
 		 * Clear board 
 		 */
 		if (lastselected == cnt) {
-		    sprintf(infostring, "Level cleared");
+		    sprintf(infostring, txt_konstruktor_Level_cleared);
 		    robbo.screws = 0;
 		    robbo.keys = 0;
 		    robbo.bullets = 0;	/* Thunor: I added this as it was missing */
@@ -1071,7 +1184,8 @@ konstruktor_click()
 		    clear_entire_board();
 		    cnt = -1;
 		} else {
-		    sprintf(infostring, "Clear level - select again to clear");
+		    sprintf(infostring,
+		    	txt_konstruktor_Clear_level_select_again_to_clear);
 		    lastclick = 50;
 		}
 		inforedraw = 1;
@@ -1079,9 +1193,9 @@ konstruktor_click()
 	    case K_SAVE:
 		if (lastselected == cnt) {
 		    if (insert == 1)
-			sprintf(infostring, "New level appended to pack");
+			sprintf(infostring, txt_konstruktor_New_level_appended_to_pack);
 		    else
-			sprintf(infostring, "Changes saved");
+			sprintf(infostring, txt_konstruktor_Changes_saved);
 		    cnt = -1;
 
 		    k_save_map();
@@ -1093,10 +1207,10 @@ konstruktor_click()
 
 		    if (insert == 1)
 			sprintf(infostring,
-				"Save - select again to save new level");
+				txt_konstruktor_Save_select_again_to_save_new_level);
 		    else
 			sprintf(infostring,
-				"Save - select again to save changes");
+				txt_konstruktor_Save_select_again_to_save_changes);
 		}
 		inforedraw = 1;
 		/*
@@ -1111,13 +1225,15 @@ konstruktor_click()
 		    level.w = 16;
 		    level.h = 31;
 		    k_view.x = 0;
-		    sprintf(infostring, "Level resized to 16x31");
+		    sprintf(infostring, "%s 16x31",
+		    	txt_konstruktor_Level_resized_to);
 		    konstruktor_viewport_init();
 		    break;
 		case 1:
 		    level.w = 32;
 		    level.h = 31;
-		    sprintf(infostring, "Level resized to 32x31");
+		    sprintf(infostring, "%s 32x31",
+		    	txt_konstruktor_Level_resized_to);
 		    konstruktor_viewport_init();
 		    break;
 		}
@@ -1159,7 +1275,8 @@ konstruktor_click()
 		    konstruktor_end();
 		    cnt = -1;
 		} else {
-		    sprintf(infostring, "Exit designer - select again to exit");
+		    sprintf(infostring,
+		    	txt_konstruktor_Exit_designer_select_again_to_exit);
 		    lastclick = 50;	/* very long click is used as
 					 * another click */
 		    inforedraw = 1;
@@ -1258,6 +1375,12 @@ konstruktor_draw_icons()
 		color >> 16 & 0xff, color >> 8 & 0xff, color & 0xff));
 
 	switch (K_icons[cnt].game_obj) {
+	case BOMB:
+		if(bombtype==1) {
+		 	k_geticoncoords(8,7,&src);
+		} else k_geticoncoords(9,1,&src);
+	    SDL_BlitSurface(icons, &src, screen, &dst);
+	    break;
 	case WALL:
 	    switch (wallnumber) {
 	    case 0:
@@ -1364,6 +1487,15 @@ konstruktor_draw_icons()
 		SDL_BlitSurface(k_icons, &src, screen, &dst);
 	    }
 	    break;
+
+	case MAGNET:
+	    k_geticoncoords(K_icons[cnt].x, K_icons[cnt].y, &src);
+	    SDL_BlitSurface(icons, &src, screen, &dst);
+	    if (rotable) {
+		k_geticoncoords(6, 1, &src);
+		SDL_BlitSurface(k_icons, &src, screen, &dst);
+	    }
+	    break;
 	case TELEPORT:
 	    k_geticoncoords(K_icons[cnt].x, K_icons[cnt].y, &src);
 	    SDL_BlitSurface(icons, &src, screen, &dst);
@@ -1459,7 +1591,7 @@ k_transform_char(int c, int state)
 	return 'l';
     case STOP:
 	return 'X';
-    case BARBED_WIRE:
+    case RADIOACTIVE_FIELD:
 	return 'k';
     case EMPTY_FIELD:
 	return '.';
@@ -1475,6 +1607,8 @@ k_transform_char(int c, int state)
 	return '#';
     case KEY:
 	return '%';
+    case BOMB2:
+	return 'B';
     case BOMB:
 	return 'b';
     case DOOR:
@@ -1595,7 +1729,11 @@ k_save_level(FILE * fdesc, int lvl)
 			board[x][y].direction);
 		break;
 	    case MAGNET:
-		fprintf(fdesc, "%d.%d.M.%d\n", x, y, board[x][y].state);
+		if(board[x][y].rotable==0) /* neurocyp: non rotated magnets are saved as usual, rotated ones we save extended */
+			fprintf(fdesc, "%d.%d.M.%d\n", x, y, board[x][y].state);
+		else
+			fprintf(fdesc, "%d.%d.M.%d.%d\n", x, y, board[x][y].state,board[x][y].rotable);
+		
 		break;
 	    case TELEPORT:
 		fprintf(fdesc, "%d.%d.&.%d.%d\n", x, y,
