@@ -159,7 +159,7 @@ int level_init (void)
 			viewport.y = 0;
 		}
 		viewport.cycles_to_dest = DELAY_LEVEL_INIT_SCROLL;
-
+		
 		#ifdef DEBUG_RECORD_DEMO
 			demo_mode (DEMO_MODE_RECORD_INITIALISE, 0);
 		#endif
@@ -182,7 +182,7 @@ void create_userpack (void)
 	FILE *fp;
 	char fullpath[256];
 	#if defined(PLATFORM_WIN32)
-	#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS)
+	#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS) || defined(PLATFORM_FREMANTLE)
 		char foldername[256];
 	#elif defined(PLATFORM_GP2X)
 	#elif defined(PLATFORM_PSP)
@@ -191,11 +191,11 @@ void create_userpack (void)
 	/* Build a platform dependent full path to the DEFAULT_USER_LEVEL_PACK */
 	fullpath[0] = 0;
 	#if defined(PLATFORM_WIN32)
-	#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS)
+	#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS) || defined(PLATFORM_FREMANTLE)
 		strcpy (fullpath, getenv ("HOME"));
-		strcat (fullpath, "/" LOCAL_DATA_DIR LEVELS_DIR DEFAULT_USER_LEVEL_PACK);
+		strcat (fullpath, "/" LOCAL_DATA_DIR "/" LEVELS_DIR "/" DEFAULT_USER_LEVEL_PACK);
 	#elif defined(PLATFORM_GP2X) || defined(PLATFORM_PSP)
-		strcpy (fullpath, PACKAGE_DATA_DIR LEVELS_DIR DEFAULT_USER_LEVEL_PACK);
+		strcpy (fullpath, PACKAGE_DATA_DIR "/" LEVELS_DIR "/" DEFAULT_USER_LEVEL_PACK);
 	#endif
 	
 	if (fullpath[0] != 0)
@@ -208,11 +208,11 @@ void create_userpack (void)
 
 			/* Create directory structure ignoring errors */
 			#if defined(PLATFORM_WIN32)
-			#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS)
+			#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS) || defined(PLATFORM_FREMANTLE)
 				strcpy (foldername, getenv ("HOME"));
 				strcat (foldername, "/" LOCAL_DATA_DIR);
 				mkdir (foldername, 0755);
-				strcat (foldername, LEVELS_DIR);
+				strcat (foldername, "/" LEVELS_DIR);
 				mkdir (foldername, 0755);
 			#elif defined(PLATFORM_GP2X)
 			#elif defined(PLATFORM_PSP)
@@ -299,7 +299,7 @@ find_all_dat_files (void)
 
 	#if defined(PLATFORM_WIN32)
 		for (count = 0; count < 1; count++)
-	#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS)
+	#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS) || defined(PLATFORM_FREMANTLE)
 		for (count = 0; count < 2; count++)
 	#elif defined(PLATFORM_GP2X) || defined(PLATFORM_PSP)
 		for (count = 0; count < 1; count++)
@@ -307,14 +307,14 @@ find_all_dat_files (void)
 	{
 		if (count == 0)
 		{
-			strcpy (foldername, PACKAGE_DATA_DIR LEVELS_DIR);
+			strcpy (foldername, PACKAGE_DATA_DIR "/" LEVELS_DIR);
 		}
 		else if (count == 1)
 		{
 			#if defined(PLATFORM_WIN32)
-			#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS)
+			#elif defined(PLATFORM_PC) || defined(PLATFORM_ZAURUS) || defined(PLATFORM_FREMANTLE)
 				strcpy (foldername, getenv ("HOME"));
-				strcat (foldername, "/" LOCAL_DATA_DIR LEVELS_DIR);
+				strcat (foldername, "/" LOCAL_DATA_DIR "/" LEVELS_DIR);
 			#elif defined(PLATFORM_GP2X)
 			#elif defined(PLATFORM_PSP)
 			#endif
@@ -326,11 +326,19 @@ find_all_dat_files (void)
 			/* Now search the directory for dat files */
 			while ((currentdirent = readdir (dir)) != NULL)
 			{
-				if (strstr (currentdirent->d_name, ".dat") != NULL)
+                                #if defined(PLATFORM_PSP)
+                                	if ((strstr (currentdirent->d_name, ".dat") != NULL) || (strstr (currentdirent->d_name, ".DAT") != NULL))
+                                #else
+                                	if (strstr (currentdirent->d_name, ".dat") != NULL)
+                                #endif
 				{
 					if (level_pack_count < MAX_LEVEL_PACKS)
 					{
-						if (strcmp (currentdirent->d_name, DEFAULT_LEVEL_PACK) == 0)
+                                                #if defined(PLATFORM_PSP)
+                                                      if (strcasecmp (currentdirent->d_name, DEFAULT_LEVEL_PACK) == 0)
+                                                #else
+                                                      if (strcmp (currentdirent->d_name, DEFAULT_LEVEL_PACK) == 0)        
+                                                #endif
 						{
 							default_dat_found = TRUE;
 						}
@@ -338,6 +346,8 @@ find_all_dat_files (void)
 						{
 							strcpy (level_packs[level_pack_count].filename,
 								foldername);
+							strcat (level_packs[level_pack_count].filename,
+								"/");
 							strcat (level_packs[level_pack_count].filename,
 								currentdirent->d_name);
 							level_pack_count++;
@@ -357,7 +367,7 @@ find_all_dat_files (void)
 	if (!default_dat_found)
 	{
 		fprintf (stdout, "Cannot find the default level file: %s\n",
-			PACKAGE_DATA_DIR LEVELS_DIR DEFAULT_LEVEL_PACK);
+			PACKAGE_DATA_DIR "/" LEVELS_DIR "/" DEFAULT_LEVEL_PACK);
 		return 1;
 	}
 
@@ -509,6 +519,9 @@ int load_level_data (int level_number)
 	int data_read = DATA_UNREAD;
 	int additional_read = DATA_UNREAD;
 	int notes_read = DATA_UNREAD;
+	/*int screws_read= DATA_UNREAD;	Thunor: redundant: not used - neurocyp:
+	 * we want to have different number of screws, than default, some levels
+	 * in robbo have different number for level, than real screws number */
 
 	/* Attempt to open the level pack */
 	strcpy (filename, level_packs[selected_pack].filename);
@@ -746,8 +759,8 @@ int load_level_data (int level_number)
 			{
 				if (sscanf (line, "%i.%i", &value_read[0], &value_read[1]) == 2)
 				{
-					if ((value_read[0] > 0 && value_read[0] < MAX_W) &&
-						(value_read[1] > 0 && value_read[1] < MAX_H))
+					if ((value_read[0] > 0 && value_read[0] <= MAX_W) &&
+						(value_read[1] > 0 && value_read[1] <= MAX_H))
 					{
 						level.w = value_read[0];
 						level.h = value_read[1];
@@ -805,6 +818,7 @@ int load_level_data (int level_number)
 						create_object (x, y, board[x][y].type);
 						switch (board[x][y].type)
 						{
+							
 							case SCREW:
 								robbo.screws++;
 								break;
@@ -944,9 +958,16 @@ int load_level_data (int level_number)
 								board[x][y].movable = value_read[3];
 								board[x][y].rotable = value_read[4];
 								board[x][y].randomrotated = value_read[5];
+								if(board[x][y].movable==1) {
+									board[x][y].state+=4;
+								}
 								break;
 							case MAGNET:
 								board[x][y].state = value_read[0];
+								if(value_count>4)   /* we would like to have rotable magnets */
+									board[x][y].rotable=value_read[1];
+								else	
+									board[x][y].rotable=0;
 							case BARRIER:
 								board[x][y].direction = value_read[0];
 								break;
@@ -1037,7 +1058,7 @@ int transform_char (char c)
 		case 'X':
 			return STOP;
 		case 'k':
-			return BARBED_WIRE;
+			return RADIOACTIVE_FIELD;
 		case '.':
 			return EMPTY_FIELD;
 		case 'R':
@@ -1054,6 +1075,8 @@ int transform_char (char c)
 			return BOX;
 		case '%':
 			return KEY;
+		case 'B':
+			return BOMB2;  /* robbo alex has at least two types of bombs */ 	
 		case 'b':
 			return BOMB;
 		case 'D':
