@@ -24,8 +24,10 @@
 /*
 #define DEBUG_LOAD_SELECTED_LOCALE
 #define DEBUG_READ_LOCALERC_FILE
+#define DEBUG_SET_LOCALE_TO_LANG
 */
-#define LOCALES_DIR "locales/"
+
+#define LOCALES_DIR "locales"
 #define LOCALERC_FILE "localerc"
 #define LOCALE_TEXT_FILE "text"
 
@@ -53,10 +55,10 @@ find_all_locales (void)
   int default_locale_found = FALSE;
 
   /* Open the locales directory */
-  if ((dir = opendir (PACKAGE_DATA_DIR LOCALES_DIR)) == NULL)
+  if ((dir = opendir (PACKAGE_DATA_DIR "/" LOCALES_DIR)) == NULL)
     {
       fprintf (stdout, "Couldn't open locales folder: %s\n",
-	       PACKAGE_DATA_DIR LOCALES_DIR);
+	       PACKAGE_DATA_DIR "/" LOCALES_DIR);
       return 1;
     }
 
@@ -69,7 +71,7 @@ find_all_locales (void)
 	  if (locale_count < MAX_LOCALES)
 	    {
 	      /* Attempt to open currentdirent->d_name/localerc to verify it's a valid locale folder  */
-	      strcpy (filename, PACKAGE_DATA_DIR LOCALES_DIR);
+	      strcpy (filename, PACKAGE_DATA_DIR "/" LOCALES_DIR "/");
 	      strcat (filename, currentdirent->d_name);
 	      strcat (filename, "/");
 	      strcat (filename, LOCALERC_FILE);
@@ -96,7 +98,7 @@ find_all_locales (void)
   if (!default_locale_found)
     {
       fprintf (stdout, "Cannot find the default locale: %s\n",
-	       PACKAGE_DATA_DIR LOCALES_DIR DEFAULT_LOCALE);
+	       PACKAGE_DATA_DIR "/" LOCALES_DIR "/" DEFAULT_LOCALE);
       return 1;
     }
   else
@@ -176,7 +178,7 @@ read_localerc_files (void)
       strcpy (locales[count].name, SINGLE_SPACE);
       strcpy (locales[count].author, SINGLE_SPACE);
       /* Attempt to open the localerc file */
-      strcpy (filename, PACKAGE_DATA_DIR LOCALES_DIR);
+      strcpy (filename, PACKAGE_DATA_DIR "/" LOCALES_DIR "/");
       strcat (filename, locales[count].foldername);
       strcat (filename, "/");
       strcat (filename, LOCALERC_FILE);
@@ -295,7 +297,7 @@ void load_selected_locale (void)
 	 * will be incremented again */
 	char filename[256], line[1024];
 	int count, count2, line_count = 0, tag_found, tag_index, row = 0;
-	#define CONFIG_ITEM_COUNT 131
+	#define CONFIG_ITEM_COUNT (6+7+59+6+2+5+5+41+49)
 	struct config_item
 	{
 		char name[60];
@@ -332,6 +334,10 @@ void load_selected_locale (void)
 		strcpy (config_items[++row].name, "[txt_intro_keys_PLATFORM_ZAURUS]");
 		config_items[row].destination = txt_intro_keys;
 		config_items[row].max_rows = TXT_INTRO_KEYS_ROWS;
+	#elif defined(PLATFORM_FREMANTLE)
+		strcpy (config_items[++row].name, "[txt_intro_keys_PLATFORM_FREMANTLE]");
+		config_items[row].destination = txt_intro_keys;
+		config_items[row].max_rows = TXT_INTRO_KEYS_ROWS;
 	#elif defined(PLATFORM_PSP)
 		strcpy (config_items[++row].name, "[txt_intro_keys_PLATFORM_PSP]");
 		config_items[row].destination = txt_intro_keys;
@@ -591,8 +597,15 @@ void load_selected_locale (void)
 	config_items[row].destination = txt_key_LSuper;
 	strcpy (config_items[++row].name, "[txt_key_RSuper]");
 	config_items[row].destination = txt_key_RSuper;
-	strcpy (config_items[++row].name, "[txt_key_AltGr]");
-	config_items[row].destination = txt_key_AltGr;
+
+	#if defined(PLATFORM_FREMANTLE)
+		strcpy (config_items[++row].name, "[txt_key_AltGr_PLATFORM_FREMANTLE]");
+		config_items[row].destination = txt_key_AltGr;
+	#else
+		strcpy (config_items[++row].name, "[txt_key_AltGr]");
+		config_items[row].destination = txt_key_AltGr;
+	#endif
+
 	strcpy (config_items[++row].name, "[txt_key_Compose]");
 	config_items[row].destination = txt_key_Compose;
 	strcpy (config_items[++row].name, "[txt_key_Help]");
@@ -612,6 +625,105 @@ void load_selected_locale (void)
 	strcpy (config_items[++row].name, "[txt_key_Undo]");
 	config_items[row].destination = txt_key_Undo;
 
+	strcpy (config_items[++row].name, "[txt_konstruktor_Ground]");
+	config_items[row].destination = txt_konstruktor_Ground;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Stop]");
+	config_items[row].destination = txt_konstruktor_Stop;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Radioactive_Field]");
+	config_items[row].destination = txt_konstruktor_Radioactive_Field;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Push_Box]");
+	config_items[row].destination = txt_konstruktor_Push_Box;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Capsule]");
+	config_items[row].destination = txt_konstruktor_Capsule;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Bomb]");
+	config_items[row].destination = txt_konstruktor_Bomb;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Bomb2]");
+	config_items[row].destination = txt_konstruktor_Bomb2;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Door]");
+	config_items[row].destination = txt_konstruktor_Door;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Box]");
+	config_items[row].destination = txt_konstruktor_Box;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Empty_Field]");
+	config_items[row].destination = txt_konstruktor_Empty_Field;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Butterfly]");
+	config_items[row].destination = txt_konstruktor_Butterfly;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Gun_Fire]");
+	config_items[row].destination = txt_konstruktor_Gun_Fire;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Force_Field]");
+	config_items[row].destination = txt_konstruktor_Force_Field;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Screw]");
+	config_items[row].destination = txt_konstruktor_Screw;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Wall]");
+	config_items[row].destination = txt_konstruktor_Wall;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Black_Wall]");
+	config_items[row].destination = txt_konstruktor_Black_Wall;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Teleport]");
+	config_items[row].destination = txt_konstruktor_Teleport;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Gun]");
+	config_items[row].destination = txt_konstruktor_Gun;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Magnet]");
+	config_items[row].destination = txt_konstruktor_Magnet;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Bear]");
+	config_items[row].destination = txt_konstruktor_Bear;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Black_Bear]");
+	config_items[row].destination = txt_konstruktor_Black_Bear;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Bird]");
+	config_items[row].destination = txt_konstruktor_Bird;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Key]");
+	config_items[row].destination = txt_konstruktor_Key;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Bullets]");
+	config_items[row].destination = txt_konstruktor_Bullets;
+	strcpy (config_items[++row].name, "[txt_konstruktor_on_map]");
+	config_items[row].destination = txt_konstruktor_on_map;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Laser_Gun]");
+	config_items[row].destination = txt_konstruktor_Laser_Gun;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Blaster_Gun]");
+	config_items[row].destination = txt_konstruktor_Blaster_Gun;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Regular_Gun]");
+	config_items[row].destination = txt_konstruktor_Regular_Gun;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Fixed]");
+	config_items[row].destination = txt_konstruktor_Fixed;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Moveable]");
+	config_items[row].destination = txt_konstruktor_Moveable;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Rotating]");
+	config_items[row].destination = txt_konstruktor_Rotating;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Moveable_Rotating]");
+	config_items[row].destination = txt_konstruktor_Moveable_Rotating;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Direction_right]");
+	config_items[row].destination = txt_konstruktor_Direction_right;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Direction_down]");
+	config_items[row].destination = txt_konstruktor_Direction_down;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Direction_left]");
+	config_items[row].destination = txt_konstruktor_Direction_left;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Direction_up]");
+	config_items[row].destination = txt_konstruktor_Direction_up;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Welcome_to_GNU_Robbo_Designer]");
+	config_items[row].destination = txt_konstruktor_Welcome_to_GNU_Robbo_Designer;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Exit_designer_select_again_to_exit]");
+	config_items[row].destination = txt_konstruktor_Exit_designer_select_again_to_exit;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Reload_level_select_again_to_reload]");
+	config_items[row].destination = txt_konstruktor_Reload_level_select_again_to_reload;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Level_reloaded]");
+	config_items[row].destination = txt_konstruktor_Level_reloaded;
+	strcpy (config_items[++row].name, "[txt_konstruktor_New_level_select_again_to_create]");
+	config_items[row].destination = txt_konstruktor_New_level_select_again_to_create;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Level_created]");
+	config_items[row].destination = txt_konstruktor_Level_created;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Save_select_again_to_save_new_level]");
+	config_items[row].destination = txt_konstruktor_Save_select_again_to_save_new_level;
+	strcpy (config_items[++row].name, "[txt_konstruktor_New_level_appended_to_pack]");
+	config_items[row].destination = txt_konstruktor_New_level_appended_to_pack;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Clear_level_select_again_to_clear]");
+	config_items[row].destination = txt_konstruktor_Clear_level_select_again_to_clear;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Level_cleared]");
+	config_items[row].destination = txt_konstruktor_Level_cleared;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Save_select_again_to_save_changes]");
+	config_items[row].destination = txt_konstruktor_Save_select_again_to_save_changes;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Changes_saved]");
+	config_items[row].destination = txt_konstruktor_Changes_saved;
+	strcpy (config_items[++row].name, "[txt_konstruktor_Level_resized_to]");
+	config_items[row].destination = txt_konstruktor_Level_resized_to;
+
 	#ifdef DEBUG_LOAD_SELECTED_LOCALE
 		printf ("*** Start %s ***\n", __func__);
 	#endif
@@ -635,7 +747,7 @@ void load_selected_locale (void)
 	#endif
 
 	/* Attempt to open the text file */
-	strcpy (filename, PACKAGE_DATA_DIR LOCALES_DIR);
+	strcpy (filename, PACKAGE_DATA_DIR "/" LOCALES_DIR "/");
 	strcat (filename, locales[selected_locale].foldername);
 	strcat (filename, "/");
 	strcat (filename, LOCALE_TEXT_FILE);
@@ -727,3 +839,64 @@ void load_selected_locale (void)
 	#endif
 }
 
+/***************************************************************************
+ * Set Locale to LANG                                                      *
+ ***************************************************************************/
+/* This will attempt to set the default locale to something equivalent to
+ * whatever is present within the LANG environment variable. This must be
+ * called after read_localerc_files and before read_resource_file so that
+ * if an rcfile is found and a locale is set within it then that will
+ * override any default set here */
+
+void set_locale_to_LANG(void) {
+	int count, length = 0, found = FALSE;
+	char *envlang = getenv("LANG");
+
+	#ifdef DEBUG_SET_LOCALE_TO_LANG
+		printf("%s: locales[selected_locale].foldername=%s\n", __func__,
+			locales[selected_locale].foldername);
+		printf("%s: LANG=%s\n", __func__, envlang);
+	#endif
+
+	/* On my GP2X getenv("LANG") returns NULL and using any string
+	 * functions on NULL will cause a segfault. Actually this is an
+	 * issue for any platform and really the return value from getenv
+	 * should always be checked for NULL before using it in any string
+	 * functions */
+
+	if (envlang != NULL) length = strlen(envlang);
+
+	if (length >= 5) {
+		length = 5;	/* en_GB is 5 chars */
+	} else if (length >= 2) {
+		length = 2;	/* en is 2 chars */
+	} else {
+		length = 0;
+	}
+	
+	while (!found && length) {
+		for (count = 0; count < locale_count; count++) {
+			if (!strncmp(locales[count].foldername, envlang, length)) {
+				found = TRUE;
+				selected_locale = count;
+				#ifdef DEBUG_SET_LOCALE_TO_LANG
+					printf("%s: A %i-char match was found\n", __func__, length);
+				#endif
+			}
+		}
+		if (length > 2) {
+			length = 2;
+		} else {
+			length = 0;
+		}
+	}
+
+	#ifdef DEBUG_SET_LOCALE_TO_LANG
+		printf("%s: locales[selected_locale].foldername=%s\n", __func__,
+			locales[selected_locale].foldername);
+		if (!found) printf("%s: No match was found\n", __func__);
+	#endif
+}
+
+
+
