@@ -19,7 +19,7 @@
  */
 
 /* Defines */
-#define MAX_LOCALES 10
+#define MAX_LOCALES 12
 #define DEFAULT_LOCALE "en_GB"
 
 #define TXT_INTRO_STORY_ROWS 4
@@ -175,6 +175,56 @@ char txt_key_Power[TXT_MAX_COLS];
 char txt_key_Euro[TXT_MAX_COLS];
 char txt_key_Undo[TXT_MAX_COLS];
 
+char txt_konstruktor_Ground[TXT_MAX_COLS];
+char txt_konstruktor_Stop[TXT_MAX_COLS];
+char txt_konstruktor_Radioactive_Field[TXT_MAX_COLS];
+char txt_konstruktor_Push_Box[TXT_MAX_COLS];
+char txt_konstruktor_Capsule[TXT_MAX_COLS];
+char txt_konstruktor_Bomb[TXT_MAX_COLS];
+char txt_konstruktor_Bomb2[TXT_MAX_COLS];
+char txt_konstruktor_Door[TXT_MAX_COLS];
+char txt_konstruktor_Box[TXT_MAX_COLS];
+char txt_konstruktor_Empty_Field[TXT_MAX_COLS];
+char txt_konstruktor_Butterfly[TXT_MAX_COLS];
+char txt_konstruktor_Gun_Fire[TXT_MAX_COLS];
+char txt_konstruktor_Force_Field[TXT_MAX_COLS];
+char txt_konstruktor_Screw[TXT_MAX_COLS];
+char txt_konstruktor_Wall[TXT_MAX_COLS];
+char txt_konstruktor_Black_Wall[TXT_MAX_COLS];
+char txt_konstruktor_Teleport[TXT_MAX_COLS];
+char txt_konstruktor_Gun[TXT_MAX_COLS];
+char txt_konstruktor_Magnet[TXT_MAX_COLS];
+char txt_konstruktor_Bear[TXT_MAX_COLS];
+char txt_konstruktor_Black_Bear[TXT_MAX_COLS];
+char txt_konstruktor_Bird[TXT_MAX_COLS];
+char txt_konstruktor_Key[TXT_MAX_COLS];
+char txt_konstruktor_Bullets[TXT_MAX_COLS];
+char txt_konstruktor_on_map[TXT_MAX_COLS];
+char txt_konstruktor_Laser_Gun[TXT_MAX_COLS];
+char txt_konstruktor_Blaster_Gun[TXT_MAX_COLS];
+char txt_konstruktor_Regular_Gun[TXT_MAX_COLS];
+char txt_konstruktor_Fixed[TXT_MAX_COLS];
+char txt_konstruktor_Moveable[TXT_MAX_COLS];
+char txt_konstruktor_Rotating[TXT_MAX_COLS];
+char txt_konstruktor_Moveable_Rotating[TXT_MAX_COLS];
+char txt_konstruktor_Direction_right[TXT_MAX_COLS];
+char txt_konstruktor_Direction_down[TXT_MAX_COLS];
+char txt_konstruktor_Direction_left[TXT_MAX_COLS];
+char txt_konstruktor_Direction_up[TXT_MAX_COLS];
+char txt_konstruktor_Welcome_to_GNU_Robbo_Designer[TXT_MAX_COLS];
+char txt_konstruktor_Exit_designer_select_again_to_exit[TXT_MAX_COLS];
+char txt_konstruktor_Reload_level_select_again_to_reload[TXT_MAX_COLS];
+char txt_konstruktor_Level_reloaded[TXT_MAX_COLS];
+char txt_konstruktor_New_level_select_again_to_create[TXT_MAX_COLS];
+char txt_konstruktor_Level_created[TXT_MAX_COLS];
+char txt_konstruktor_Save_select_again_to_save_new_level[TXT_MAX_COLS];
+char txt_konstruktor_New_level_appended_to_pack[TXT_MAX_COLS];
+char txt_konstruktor_Clear_level_select_again_to_clear[TXT_MAX_COLS];
+char txt_konstruktor_Level_cleared[TXT_MAX_COLS];
+char txt_konstruktor_Save_select_again_to_save_changes[TXT_MAX_COLS];
+char txt_konstruktor_Changes_saved[TXT_MAX_COLS];
+char txt_konstruktor_Level_resized_to[TXT_MAX_COLS];
+
 struct locale {
 	char foldername[100];		/* e.g. de_DE, en_GB, es_ES, pl_PL ... */
 	char name[60];				/* e.g. Deutsch, English, Español, Polski ... */
@@ -191,6 +241,8 @@ int find_all_locales(void);
 void read_localerc_files(void);
 void sort_locales(void);
 void load_selected_locale(void);
+void set_locale_to_LANG(void);
+
 
 
 
