@@ -201,21 +201,30 @@ int read_resource_file (char *filename)
 		}
 		else if (!strncmp (line, "[filename]", 10))
 		{
-			fscanf (fp, "%s", read_level_packs[read_pack_count].filename);
+			if (read_pack_count < MAX_LEVEL_PACKS)
+				fscanf (fp, "%s", read_level_packs[read_pack_count].filename);
 		}
 		else if (!strncmp (line, "[level_reached]", 15))
 		{
-			fscanf (fp, "%i", &read_level_packs[read_pack_count].level_reached);
+			if (read_pack_count < MAX_LEVEL_PACKS)
+				fscanf (fp, "%i", &read_level_packs[read_pack_count].level_reached);
 		}
 		else if (!strncmp (line, "[level_selected]", 16))
 		{
-			fscanf (fp, "%i", &read_level_packs[read_pack_count].level_selected);
+			if (read_pack_count < MAX_LEVEL_PACKS)
+				fscanf (fp, "%i", &read_level_packs[read_pack_count].level_selected);
 		}
 		else if (!strncmp (line, "[selected]", 10))
 		{
-			fscanf (fp, "%i", &read_level_packs[read_pack_count].selected);
-			read_pack_count++;
-			if (read_pack_count >= MAX_LEVEL_PACKS) break;
+			if (read_pack_count < MAX_LEVEL_PACKS)
+			{
+				fscanf (fp, "%i", &read_level_packs[read_pack_count].selected);
+				read_pack_count++;
+				if (read_pack_count >= MAX_LEVEL_PACKS)
+					fprintf (stdout, "There are too many level packs recorded "
+						"within the rcfile (max %i). Possibly there are some "
+						"historical entries that you can delete.\n", MAX_LEVEL_PACKS);
+			}
 		}
 		else if (!strncmp (line, "[ACTION_UP.device]", 18))
 		{
