@@ -97,8 +97,8 @@ typedef struct msgbox {
 } MSG_Box;
 
 /* Function prototypes */
-void show_game_area(void);
-void show_game_area_fade(int subfunction, int type);
+int show_game_area(void);
+int show_game_area_fade(int subfunction, int type);
 SDL_Rect set_rect(int x, int y, int w, int h);
 void clear_screen(void);
 int set_video_mode(void);
