@@ -27,7 +27,7 @@
 #define DEBUG_READ_SKIN_PROJECT_COLOURS
 */
 
-#define SKINS_DIR "skins/"
+#define SKINS_DIR "skins"
 #define SKINRC_FILE "skinrc"
 #ifdef PLATFORM_ZAURUS
   #define IMG_ICONS32 "icons32.bmp"
@@ -77,10 +77,10 @@ find_all_skins (void)
   int default_skin_found = FALSE;
 
   /* Open the skins directory */
-  if ((dir = opendir (PACKAGE_DATA_DIR SKINS_DIR)) == NULL)
+  if ((dir = opendir (PACKAGE_DATA_DIR "/" SKINS_DIR)) == NULL)
     {
       fprintf (stdout, "Couldn't open skins folder: %s\n",
-	       PACKAGE_DATA_DIR SKINS_DIR);
+	       PACKAGE_DATA_DIR "/" SKINS_DIR);
       return 1;
     }
 
@@ -93,13 +93,17 @@ find_all_skins (void)
 	  if (skin_count < MAX_SKINS)
 	    {
 	      /* Attempt to open currentdirent->d_name/skinrc to verify it's a valid skin folder  */
-	      strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+	      strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
 	      strcat (filename, currentdirent->d_name);
 	      strcat (filename, "/");
 	      strcat (filename, SKINRC_FILE);
 	      if ((fp = fopen (filename, "r")) != NULL)
 		{
-		  if (!strcmp (currentdirent->d_name, DEFAULT_SKIN))
+                  #if defined(PLATFORM_PSP)
+		  	if (!strcasecmp (currentdirent->d_name, DEFAULT_SKIN))
+                  #else
+		  	if (!strcmp (currentdirent->d_name, DEFAULT_SKIN))
+                  #endif
 		    {
 		      default_skin_found = TRUE;
 		    }
@@ -120,7 +124,7 @@ find_all_skins (void)
   if (!default_skin_found)
     {
       fprintf (stdout, "Cannot find the default skin: %s\n",
-	       PACKAGE_DATA_DIR SKINS_DIR DEFAULT_SKIN);
+	       PACKAGE_DATA_DIR "/" SKINS_DIR "/" DEFAULT_SKIN);
       return 1;
     }
   else
@@ -174,7 +178,7 @@ read_skinrc_files (void)
 
       skins[count].help_tile_colour = HELP_TILE_COLOUR;
       /* Attempt to open the skinrc file */
-      strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+      strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
       strcat (filename, skins[count].foldername);
       strcat (filename, "/");
       strcat (filename, SKINRC_FILE);
@@ -476,7 +480,7 @@ read_skin_project_colours (void)
   skins[selected_skin].designer_OBJV_tile_colour = DESIGNER_OBJV_TILE_COLOUR;
 
   /* Attempt to open the skinrc file */
-  strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+  strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
   strcat (filename, skins[selected_skin].foldername);
   strcat (filename, "/");
   strcat (filename, SKINRC_FILE);
@@ -672,7 +676,7 @@ read_skin_level_colour_override (void)
   int colour_read = DATA_UNREAD;
 
   /* Attempt to open the skinrc file */
-  strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+  strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
   strcat (filename, skins[selected_skin].foldername);
   strcat (filename, "/");
   strcat (filename, SKINRC_FILE);
@@ -902,7 +906,7 @@ load_selected_skin (void)
 
 	for (count = 0; count < 6; count++)
 	{
-		strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+		strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
 		strcat (filename, skins[selected_skin].foldername);
 		strcat (filename, "/");
 		if (count == 0)
@@ -1120,7 +1124,7 @@ load_selected_skin (void)
 void set_wm_icon (void) {
 	char filename[256];
 
-	strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+	strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
 	strcat (filename, skins[selected_skin].foldername);
 	strcat (filename, "/");
 	strcat (filename, IMG_WM_ICON);
@@ -1163,7 +1167,7 @@ create_skin_preview (void)
 	char filename[256];
 	int xpos, ypos;
 
-	strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+	strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
 	strcat (filename, skins[temp_selected_skin].foldername);
 	strcat (filename, "/");
 	
@@ -1282,7 +1286,7 @@ load_TTF_font ()
   char filename[256];
   int fontsize = 0;
 
-  strcpy (filename, PACKAGE_DATA_DIR SKINS_DIR);
+  strcpy (filename, PACKAGE_DATA_DIR "/" SKINS_DIR "/");
   strcat (filename, skins[selected_skin].foldername);
   strcat (filename, "/");
 
