@@ -30,8 +30,8 @@
 /*
  * files and stuff 
  */
-#define SOUNDS_DIR "sounds/"
-#define MUSIC_DIR "music/"
+#define SOUNDS_DIR "sounds"
+#define MUSIC_DIR "music"
 
 /*
  * tags for the soundskin 
@@ -87,6 +87,8 @@ char            kill_file[MAXFNAMELEN];
 char            magnet_file[MAXFNAMELEN];
 char            exit_open_file[MAXFNAMELEN];
 
+
+int allocated_channels=-1;
 int             destroyed_playlist = 0;
 int             next_song = 0;
 int             absent = 1;
@@ -357,7 +359,7 @@ make_playlist(void)
     int             song_count = 0;
 
     destroy_playlist();
-    sprintf(musicpath, "%s/%s", PACKAGE_DATA_DIR, MUSIC_DIR);
+    sprintf(musicpath, "%s/%s/", PACKAGE_DATA_DIR, MUSIC_DIR);
     next_song = 0;
 
     if ((dir = opendir(musicpath)) == NULL) {	/* no music, means we will 
@@ -413,11 +415,11 @@ load_soundskin(char *fname)
 	sounds[c].initialized = SND_MISSING;
     }
 
-    sprintf(name, "%s%s/skins/%s", PACKAGE_DATA_DIR, SOUNDS_DIR, fname);
+    sprintf(name, "%s/%s/skins/%s", PACKAGE_DATA_DIR, SOUNDS_DIR, fname);
     if ((fd = fopen(name, "r")) == NULL) {	/* no skin file, well,
 						 * what a pity, let's try
 						 * the default one */
-	sprintf(name, "%s%s/skins/default.dat", PACKAGE_DATA_DIR,
+	sprintf(name, "%s/%s/skins/default.dat", PACKAGE_DATA_DIR,
 		SOUNDS_DIR);
 	if ((fd = fopen(name, "r")) == NULL)	/* hmmm no default sound * 
 						 * skin, how strange */
@@ -545,7 +547,7 @@ load_samples(void)
 	if (sounds[c].initialized == SND_MISSING)	/* skip missing *
 							 * samples */
 	    continue;
-	sprintf(fullpath, "%s%s%s", PACKAGE_DATA_DIR, SOUNDS_DIR,
+	sprintf(fullpath, "%s/%s/%s", PACKAGE_DATA_DIR, SOUNDS_DIR,
 		sounds[c].fname);
 #ifdef DEBUG_SOUND
 	printf("*** load samples from %s\n", fullpath);
@@ -633,6 +635,7 @@ play_sound(int event, int vol)
 {
     int             chan = 0;
     int             c = 0;
+    int channels=Mix_Playing(-1);
     if (sound == 0)		/* no sound, means no sound */
 	return;
     if (sfx_vol == 0)
@@ -647,11 +650,19 @@ play_sound(int event, int vol)
 	break;
     case SND_HALF:
 	vol = sfx_vol / 2;
+	if(channels>allocated_channels-5)  /* We want at least 5 channels to be available, in order to play quiet sounds */
+		return;
+	break;
+  case SND_QUIET:
+	vol = sfx_vol / 8;
+	if(channels>allocated_channels-5) 
+		return;
 	break;
     case SND_MUTE:
 	vol = 0;
 	break;
     case SND_NORM:
+
 	vol = sfx_vol;
 	break;
     default:
@@ -662,11 +673,13 @@ play_sound(int event, int vol)
 	vol = sfx_vol / (vol - SND_FULL);
 	break;
     }
+	
     for (c = 0; sounds[c].type != 0; c++) {
 	if (sounds[c].type == event) {
 	    if (sounds[c].initialized == SND_INIT) {
-		Mix_VolumeChunk(sounds[c].s_sample, vol);
+		//Mix_VolumeChunk(sounds[c].s_sample, vol);
 		chan = Mix_PlayChannel(-1, sounds[c].s_sample, 0);
+		Mix_Volume(chan,vol);
 	    }
 	    break;
 	}
@@ -682,7 +695,11 @@ audio_open()
     int             audio_rate = SND_RATE;
     Uint16          audio_format = AUDIO_S16SYS;
     int             audio_channels = 2;
-    int             audio_buffers = 4096;
+#if defined(PLATFORM_GP2X) && defined(TOOLCHAIN_OPEN2X)
+    int             audio_buffers = 256;
+#else
+    int             audio_buffers = 1024;
+#endif
 
     if (audio_opened() == 0) {	/* check if we already initialized sound
 				 * subsystem */
@@ -691,13 +708,14 @@ audio_open()
 	    ("audio_rate=%i audio_format=%i audio_channels=%i audio_buffers=%i\n",
 	     audio_rate, audio_format, audio_channels, audio_buffers);
 #endif
-	if (Mix_OpenAudio
-	    (audio_rate, audio_format, audio_channels, audio_buffers)
-	    != 0) {		/* it seems we will not have the sound
-				 * after all */
-	    fprintf(stderr, "Unable to initialize audio: %s\n",
-		    Mix_GetError());
+	if (Mix_OpenAudio (audio_rate, audio_format, audio_channels, audio_buffers) != 0) {		/* it seems we will not have the sound
+															 * after all */
+	    fprintf(stderr, "Unable to initialize audio: %s\n", Mix_GetError());
 	    sound = 0;
+	} else {
+		allocated_channels=Mix_AllocateChannels(SND_CHANNELS);
+		printf("Managed to allocate %d sound channels \n",allocated_channels);
+
 	}
     }
 
